'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var nanoCss = require('nano-css');
var cache = require('nano-css/addon/cache');
var nesting = require('nano-css/addon/nesting');
var rule = require('nano-css/addon/rule');
var unitless = require('nano-css/addon/unitless');
var jsx = require('nano-css/addon/jsx');
var emmet = require('nano-css/addon/emmet');

function _typeof(obj) {
  if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
    _typeof = function (obj) {
      return typeof obj;
    };
  } else {
    _typeof = function (obj) {
      return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
    };
  }

  return _typeof(obj);
}

function _classCallCheck(instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
}

function _defineProperties(target, props) {
  for (var i = 0; i < props.length; i++) {
    var descriptor = props[i];
    descriptor.enumerable = descriptor.enumerable || false;
    descriptor.configurable = true;
    if ("value" in descriptor) descriptor.writable = true;
    Object.defineProperty(target, descriptor.key, descriptor);
  }
}

function _createClass(Constructor, protoProps, staticProps) {
  if (protoProps) _defineProperties(Constructor.prototype, protoProps);
  if (staticProps) _defineProperties(Constructor, staticProps);
  return Constructor;
}

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _inherits(subClass, superClass) {
  if (typeof superClass !== "function" && superClass !== null) {
    throw new TypeError("Super expression must either be null or a function");
  }

  subClass.prototype = Object.create(superClass && superClass.prototype, {
    constructor: {
      value: subClass,
      writable: true,
      configurable: true
    }
  });
  if (superClass) _setPrototypeOf(subClass, superClass);
}

function _getPrototypeOf(o) {
  _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
    return o.__proto__ || Object.getPrototypeOf(o);
  };
  return _getPrototypeOf(o);
}

function _setPrototypeOf(o, p) {
  _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
    o.__proto__ = p;
    return o;
  };

  return _setPrototypeOf(o, p);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

function _objectWithoutProperties(source, excluded) {
  if (source == null) return {};

  var target = _objectWithoutPropertiesLoose(source, excluded);

  var key, i;

  if (Object.getOwnPropertySymbols) {
    var sourceSymbolKeys = Object.getOwnPropertySymbols(source);

    for (i = 0; i < sourceSymbolKeys.length; i++) {
      key = sourceSymbolKeys[i];
      if (excluded.indexOf(key) >= 0) continue;
      if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;
      target[key] = source[key];
    }
  }

  return target;
}

function _assertThisInitialized(self) {
  if (self === void 0) {
    throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
  }

  return self;
}

function _possibleConstructorReturn(self, call) {
  if (call && (typeof call === "object" || typeof call === "function")) {
    return call;
  }

  return _assertThisInitialized(self);
}

function _slicedToArray(arr, i) {
  return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
}

function _arrayWithHoles(arr) {
  if (Array.isArray(arr)) return arr;
}

function _iterableToArrayLimit(arr, i) {
  var _arr = [];
  var _n = true;
  var _d = false;
  var _e = undefined;

  try {
    for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
      _arr.push(_s.value);

      if (i && _arr.length === i) break;
    }
  } catch (err) {
    _d = true;
    _e = err;
  } finally {
    try {
      if (!_n && _i["return"] != null) _i["return"]();
    } finally {
      if (_d) throw _e;
    }
  }

  return _arr;
}

function _nonIterableRest() {
  throw new TypeError("Invalid attempt to destructure non-iterable instance");
}

// The minimal theme that is required right now...
var theme = {
  fadedWhite: '#FAFAFA',
  fadedBlack: '#424242',
  light: {
    primary: '#00897B',
    // Teal 600
    primaryFg: '#FAFAFA',
    // Grey 50
    secondary: '#FFB300',
    // Amber 600
    secondaryFg: '#212121',
    // Grey  900
    disabled: '#F5F5F5',
    // Grey 100
    disabledFg: '#E0E0E0' // Grey 300

  }
};

var KamamanaContext = React__default.createContext(theme);
var KamamanaProvider = function KamamanaProvider(_ref) {
  var children = _ref.children,
      kTheme = _ref.kTheme;
  return React__default.createElement(KamamanaContext.Provider, {
    value: kTheme
  }, children);
};
var KamamanaConsumer = KamamanaContext.Consumer;

var nano = nanoCss.create({
  pfx: 'kamamana-',
  h: React.createElement
}); // Add addons you would like to use.

cache.addon(nano);
nesting.addon(nano);
rule.addon(nano);
unitless.addon(nano);
jsx.addon(nano);
emmet.addon(nano); // Supports Emmet abbreviations

var rule$1 = nano.rule,
    jsx$1 = nano.jsx;

var Button = jsx$1('button', {
  d: 'flex',
  ai: 'center',
  bxz: 'border-box',
  bdrs: '2px',
  fz: '16px',
  lh: 1.4,
  m: '0 8px 15px 0',
  p: '8px 15px',
  cur: 'pointer',
  trs: 'all 0.3s ease-out',
  '&:focus': {
    ol: 'none'
  },
  '& .btn-icon': {
    mr: 8
  },
  '& .btn-text': {
    fz: '14px'
  },
  '& .btn-icon + .btn-text': {
    ml: '8px'
  }
}, 'ButtonStyled');
var disabledCSS = function disabledCSS(context) {
  return {
    cur: 'not-allowed',
    bgc: context.light.disabled,
    c: context.light.disabledFg,
    bd: "1px solid ".concat(context.light.disabledFg)
  };
};

var Icon =
/*#__PURE__*/
function (_React$Component) {
  _inherits(Icon, _React$Component);

  function Icon() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, Icon);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(Icon)).call.apply(_getPrototypeOf2, [this].concat(args)));
    _this.state = {
      module: null
    };
    return _this;
  }

  _createClass(Icon, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      var _this2 = this;

      this.props.icon && Promise.resolve(require("./".concat(this.props.icon))).then(function (module) {
        _this2.setState({
          module: module.default
        });
      });
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props = this.props,
          icon = _this$props.icon,
          className = _this$props.className,
          rest = _objectWithoutProperties(_this$props, ["icon", "className"]);

      var Component = this.state.module;
      return Component ? React__default.createElement(Component, _extends({
        className: className
      }, rest)) : null;
    }
  }]);

  return Icon;
}(React__default.Component);

var compose = (function () {
  for (var _len = arguments.length, fns = new Array(_len), _key = 0; _key < _len; _key++) {
    fns[_key] = arguments[_key];
  }

  return fns.reduce(function (composedFn, fn) {
    return function () {
      return fn(composedFn.apply(void 0, arguments));
    };
  });
});

/**
 * Returns and array of [r, g, b], else []
 * @param {string} rgbString RGB string of format rgb(r, g, b)
 */

var splitRGBfromRGBString = function splitRGBfromRGBString(rgbString) {
  var result = /^rgb\(\s*?(\d{1,3}),\s*(\d{1,3}),\s*(\d{1,3})\s*\)$/i.exec(rgbString);
  return result ? result.splice(1) : [];
};
var extractIntegerFromHexString = function extractIntegerFromHexString(hexString) {
  // Expand shorthand form (e.g. "03F") to full form (e.g. "0033FF")
  var shorthandRegex = /^#?([a-f\d])([a-f\d])([a-f\d])$/i;

  var _hex = hexString && hexString.replace(shorthandRegex, function (m, r, g, b) {
    return "#".concat(r + r).concat(g + g).concat(b + b);
  });

  var result = _hex ? /^#?([a-f\d]{2})([a-f\d]{2})([a-f\d]{2})$/i.exec(_hex) : [];
  return result ? result.splice(1).map(function (val) {
    return parseInt(val, 16);
  }) : [];
};
var componentToHex = function componentToHex(c) {
  if (c / 255 < 0 || c / 255 > 1) {
    return null;
  }

  var hex = c.toString(16);
  return hex.length === 1 ? "0".concat(hex) : hex;
};
/**
 * Excepts a string of format `rgb(r, g, b)`
 * @param {string} rgb RGB CSS String to convert to Hex
 */

var rgbToHex = function rgbToHex(rgb) {
  var r, g, b;

  if (!rgb) {
    return null;
  }

  if (typeof rgb === 'string') {
    var _splitRGBfromRGBStrin = splitRGBfromRGBString(rgb).map(function (val) {
      return componentToHex(parseInt(val));
    });

    var _splitRGBfromRGBStrin2 = _slicedToArray(_splitRGBfromRGBStrin, 3);

    r = _splitRGBfromRGBStrin2[0];
    g = _splitRGBfromRGBStrin2[1];
    b = _splitRGBfromRGBStrin2[2];
  } else if (_typeof(rgb) === 'object' && rgb.hasOwnProperty('r')) {
    r = componentToHex(parseInt(rgb.r));
    g = componentToHex(parseInt(rgb.g));
    b = componentToHex(parseInt(rgb.b));
  }

  return r && g && b ? "#".concat(r).concat(g).concat(b) : null;
};
var hexToRgb = function hexToRgb(hex) {
  var _extractIntegerFromHe = extractIntegerFromHexString(hex),
      _extractIntegerFromHe2 = _slicedToArray(_extractIntegerFromHe, 3),
      r = _extractIntegerFromHe2[0],
      g = _extractIntegerFromHe2[1],
      b = _extractIntegerFromHe2[2];

  return !isNaN(r) && !isNaN(g) && !isNaN(b) ? {
    r: r,
    g: g,
    b: b
  } : null;
};
var getBoundedChangeAmount = function getBoundedChangeAmount() {
  var amount = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;

  var _amount = amount < 0 ? 0 : amount > 100 ? 100 : amount;

  return _amount / 100 * 255;
};
/**
 * This method is not the efficient way for lightening the colors.. Will understand and figure things out later
 * v0.1 :P
 * It's easiest possible way to shade colors, help taken from https://stackoverflow.com/a/13542669/2849127
 */

var shader = function shader(color, amount) {
  if (color && color.hasOwnProperty('r') && color.hasOwnProperty('g') && color.hasOwnProperty('b')) {
    var r = color.r,
        g = color.g,
        b = color.b;
    r = r + amount;
    g = g + amount;
    b = b + amount;
    return {
      r: r > 255 ? 255 : r < 0 ? 0 : Math.round(r),
      g: g > 255 ? 255 : g < 0 ? 0 : Math.round(g),
      b: b > 255 ? 255 : b < 0 ? 0 : Math.round(b)
    };
  }

  return color;
}; // Wanted to use composition here, but not sure if it's possible with these functions??

var lighten = function lighten(color, amount) {
  return shader(color, getBoundedChangeAmount(amount));
};
var darken = function darken(color, amount) {
  return shader(color, -getBoundedChangeAmount(amount));
}; // Help taken from https://github.com/mapbox/react-colorpickr/blob/5c7d8498c539a99c1330a83b4c7d6a79b7daaff9/src/colorfunc.js#L6

var isDark = function isDark(color) {
  if (color) {
    var r = color.r,
        g = color.g,
        b = color.b;
    return !(r * 0.299 + g * 0.587 + b * 0.114 > 186);
  }

  return false;
};
var isDarkHex = compose(hexToRgb, isDark);
var lightenHexToAmount = function lightenHexToAmount(amount) {
  return compose(hexToRgb, function (rgbColor) {
    return lighten(rgbColor, amount);
  }, rgbToHex);
};
var darkenHexToAmount = function darkenHexToAmount(amount) {
  return compose(hexToRgb, function (rgbColor) {
    return darken(rgbColor, amount);
  }, rgbToHex);
};

var isString = function isString(string) {
  return typeof string === 'string' || string instanceof String;
};

var filterProps = (function (props) {
  var style = props.style,
      bgcHover = props.bgcHover,
      fgcHover = props.fgcHover,
      type = props.type,
      block = props.block,
      text = props.text,
      disabled = props.disabled,
      icon = props.icon,
      iconW = props.iconW,
      iconH = props.iconH,
      className = props.className,
      rest = _objectWithoutProperties(props, ["style", "bgcHover", "fgcHover", "type", "block", "text", "disabled", "icon", "iconW", "iconH", "className"]);

  return {
    custom: {
      style: style,
      bgcHover: bgcHover,
      fgcHover: fgcHover,
      type: type,
      block: block,
      text: text,
      disabled: disabled,
      icon: icon,
      iconW: iconW,
      iconH: iconH,
      className: className
    },
    rest: rest
  };
});

var darkenHexByTen = darkenHexToAmount(10);

var Button$1 =
/*#__PURE__*/
function (_Component) {
  _inherits(Button$$1, _Component);

  function Button$$1() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, Button$$1);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(Button$$1)).call.apply(_getPrototypeOf2, [this].concat(args)));

    _this.getGhostCSS = function (context) {
      var btnTheme = context.btn || {};
      var bgc = 'transparent';
      var bgcHover = bgc;
      var fgc = _this.props.style.c || btnTheme.c || context.fadedWhite;
      var fgcHover = _this.props.fgcHover || context.light.primary;
      return {
        bgc: bgc,
        bgcHover: bgcHover,
        fgc: fgc,
        fgcHover: fgcHover,
        bdc: _this.props.style.bdc || btnTheme.bdc || fgc,
        bdcHover: _this.props.bdcHover || fgcHover
      };
    };

    _this.getBorderedCSS = function (context) {
      var btnTheme = context.btn || {};
      var bgc = context.fadedWhite;
      var bgcHover = bgc;
      var fgc = _this.props.style.c || btnTheme.c || context.fadedBlack;
      var fgcHover = _this.props.fgcHover || context.light.primary;
      return {
        bgc: bgc,
        bgcHover: bgcHover,
        fgc: fgc,
        fgcHover: fgcHover,
        bdc: _this.props.style.bdc || btnTheme.bdc || fgc,
        bdcHover: _this.props.bdcHover || fgcHover
      };
    };

    _this.getDefaultCSS = function (context) {
      var btnTheme = context.btn || {};
      var bgc = _this.props.style.bgc || btnTheme.bgc || context.light.primary;
      var bgcHover = _this.props.bgcHover || darkenHexByTen(_this.props.style.bgc || btnTheme.bgc || context.light.primary);
      return {
        bgc: bgc,
        bgcHover: bgcHover,
        fgc: _this.props.style.c || btnTheme.c || context.fadedWhite,
        fgcHover: _this.props.fgcHover || (isDarkHex(bgcHover) ? context.fadedWhite : context.fadedBlack),
        bdc: _this.props.style.bdc || btnTheme.bdc || bgc,
        bdcHover: _this.props.bdcHover || bgcHover
      };
    };

    _this.getCSSFromType = function (type, context) {
      switch (type) {
        case 'ghost':
          return _this.getGhostCSS(context);

        case 'bordered':
          return _this.getBorderedCSS(context);

        default:
          return _this.getDefaultCSS(context);
      }
    };

    _this.getCSS = function (type, context) {
      var css = _this.getCSSFromType(type, context);

      return _extends({
        bgc: css.bgc,
        c: css.fgc,
        bd: "1px solid ".concat(css.bdc),
        '&:hover': {
          '&:not([disabled])': {
            bgc: css.bgcHover,
            c: css.fgcHover,
            bd: "1px solid ".concat(css.bdcHover)
          }
        },
        '&[disabled], &.disabled': disabledCSS(context)
      }, _this.props.style);
    };

    return _this;
  }

  _createClass(Button$$1, [{
    key: "render",
    value: function render() {
      var _this2 = this;

      var _filterProps = filterProps(this.props),
          custom = _filterProps.custom,
          rest = _filterProps.rest;

      return React__default.createElement(KamamanaConsumer, null, function (context) {
        return React__default.createElement(Button, _extends({
          css: _this2.getCSS(custom.type, context),
          disabled: custom.disabled,
          className: custom.className
        }, rest), custom.icon && React__default.createElement(Icon, {
          className: "btn-icon",
          icon: custom.icon,
          w: custom.iconW,
          h: custom.iconH
        }), React__default.createElement("span", null, custom.text));
      });
    }
  }]);

  return Button$$1;
}(React.Component);

Button$1.defaultProps = {
  style: {},
  iconW: '16px',
  iconH: '16px'
};

// Default Theme Object used by this module, Should be overriden and passed to components

var CardStyled = jsx$1('div', {
  bxz: 'border-box',
  bdrs: '2px',
  fz: '16px',
  lh: 1.4,
  p: '15px',
  bxsh: '0 0 15px -8px rgba(0,0,0,0.1), 0 2px 5px rgba(0,0,0,0.2)'
}, 'CardStyled');

var CardTitleStyled = jsx$1('div', {
  fz: 24,
  mb: 15
}, 'CardTitleStyled');

var CardTitle =
/*#__PURE__*/
function (_React$Component) {
  _inherits(CardTitle, _React$Component);

  function CardTitle() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, CardTitle);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(CardTitle)).call.apply(_getPrototypeOf2, [this].concat(args)));

    _this.getCSS = function (context) {
      return _extends({
        c: context.fadedBlack
      }, _this.props.style);
    };

    return _this;
  }

  _createClass(CardTitle, [{
    key: "render",
    value: function render() {
      var _this2 = this;

      var _this$props = this.props,
          className = _this$props.className,
          style = _this$props.style;
      return React__default.createElement(KamamanaConsumer, null, function (context) {
        return React__default.createElement(CardTitleStyled, {
          css: _this2.getCSS(context),
          className: className
        }, _this2.props.children);
      });
    }
  }]);

  return CardTitle;
}(React__default.Component);

CardTitle.defaultProps = {
  className: 'title'
};

var CardContentStyled = jsx$1('div', {}, 'CardContentStyled');

var lightenHexBy10 = lightenHexToAmount(10);

var CardContent =
/*#__PURE__*/
function (_React$Component) {
  _inherits(CardContent, _React$Component);

  function CardContent() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, CardContent);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(CardContent)).call.apply(_getPrototypeOf2, [this].concat(args)));

    _this.getCSS = function (context) {
      return _extends({
        c: lightenHexBy10(context.fadedBlack)
      }, _this.props.style);
    };

    return _this;
  }

  _createClass(CardContent, [{
    key: "render",
    value: function render() {
      var _this2 = this;

      var _this$props = this.props,
          className = _this$props.className,
          style = _this$props.style;
      return React__default.createElement(KamamanaConsumer, null, function (context) {
        return React__default.createElement(CardContentStyled, {
          css: _this2.getCSS(context),
          className: className
        }, _this2.props.children);
      });
    }
  }]);

  return CardContent;
}(React__default.Component);

CardContent.defaultProps = {
  className: 'content'
};

var Card =
/*#__PURE__*/
function (_React$PureComponent) {
  _inherits(Card, _React$PureComponent);

  function Card() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, Card);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(Card)).call.apply(_getPrototypeOf2, [this].concat(args)));

    _this.getTitle = function (context) {
      if (!_this.props.title) {
        return null;
      } else if (!isString(_this.props.title) && React__default.Children.count(_this.props.title) === 1 && React__default.Children.only(_this.props.title).type === CardTitle) {
        return _this.props.title;
      }

      return React__default.createElement(CardTitle, {
        style: _this.getCSS(context)
      }, _this.props.title);
    };

    _this.getContent = function (context) {
      if (!isString(_this.props.children) && React__default.Children.count(_this.props.children) === 1 && React__default.Children.only(_this.props.children).type === CardContent) {
        return _this.props.children;
      }

      return React__default.createElement(CardContent, {
        style: _this.getCSS(context)
      }, _this.props.children);
    };

    _this.getCSS = function (context) {
      return _extends({
        c: context.fadedBlack,
        bgc: context.fadedWhite
      }, _this.props.style);
    };

    return _this;
  }

  _createClass(Card, [{
    key: "render",
    value: function render() {
      var _this2 = this;

      return React__default.createElement(KamamanaConsumer, null, function (context) {
        return React__default.createElement(CardStyled, {
          css: _this2.getCSS(context)
        }, _this2.getTitle(context), _this2.getContent(context));
      });
    }
  }]);

  return Card;
}(React__default.PureComponent);

Card.defaultProps = {
  style: {}
};

var Container = jsx$1('div', {
  d: 'flex'
}, 'FlexContainer');

var FlexItem = jsx$1('div', {
  fxg: 1,
  fxs: 1
}, 'FlexItem');

var Flexbox =
/*#__PURE__*/
function (_React$PureComponent) {
  _inherits(Flexbox, _React$PureComponent);

  function Flexbox(_props) {
    var _this;

    _classCallCheck(this, Flexbox);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Flexbox).call(this, _props));

    _this.prefix = function (props, colSpanList) {
      var childCount = React__default.Children.count(props.children);
      var total, colCount;

      if (colSpanList) {
        total = colSpanList.reduce(function (sum, n) {
          return sum + n;
        }, 0);
        colCount = colSpanList.length;
      } else {
        colCount = childCount;
      }

      if (colCount === childCount) {
        return React__default.Children.map(props.children, function (child, i) {
          if (child.type === Flexbox) {
            return child;
          }

          var width = colSpanList ? colSpanList[i] * 100 / total : 100;

          if (child.type === FlexItem) {
            return React__default.cloneElement(child, {
              css: _extends({}, child.props.style, {
                fxb: "".concat(width, "%")
              })
            }, child.props.children);
          }

          var _child$props = child.props,
              itemStyle = _child$props.itemStyle,
              rest = _objectWithoutProperties(_child$props, ["itemStyle"]);

          return React__default.createElement(FlexItem, {
            css: _extends({}, itemStyle, {
              fxb: "".concat(width, "%")
            })
          }, React__default.cloneElement(child, _extends({}, rest), child.props.children));
        });
      }

      throw new Error('Child Count must be equal to Column Count');
    };

    var _colSpanList = _props.cols ? _props.cols.split(':').map(function (num) {
      return parseInt(num, 10);
    }) : null;

    _this.state = {
      // Surround each Child with FlexItem for proper, width calculations...
      children: _this.prefix(_props, _colSpanList),
      colSpanList: _colSpanList
    };
    return _this;
  } // This method helps in wrapping flex items inside <FlexItemStyled /> if already not inside it.
  // Helps in removing extra code for <FlexItemStyled /> Wrappers...


  _createClass(Flexbox, [{
    key: "render",
    value: function render() {
      var css = _extends({}, this.props.style);

      return React__default.createElement(Container, {
        css: css
      }, this.state.children);
    }
  }]);

  return Flexbox;
}(React__default.PureComponent);

Flexbox.defaultProps = {
  style: {
    fxd: 'row'
  }
};

exports.KamamanaProvider = KamamanaProvider;
exports.KamamanaConsumer = KamamanaConsumer;
exports.Button = Button$1;
exports.Card = Card;
exports.CardTitle = CardTitle;
exports.CardContent = CardContent;
exports.Flexbox = Flexbox;
exports.FlexItem = FlexItem;
exports.nano = nano;
exports.rule = rule$1;
exports.jsx = jsx$1;
